# GEneral PREprocessing Framework for TEXT (gepref_text)
---

`gepref_text` is an implementation of the [gepref framework](https://github.com/juselara1/gepref/tree/main) for text preprocessing.

To install `gepref_text`:

```sh
pip install gepref_text
```
